@@ -121,9 +121,11 @@ namespace pystan {
       sampler_ptr -> get_sampler_params(sampler_values);
         
       std::vector<double> param_values;
-      model.write_array(rng, 
-                        const_cast<std::vector<double>&>(s.cont_params()),
-                        const_cast<std::vector<int>&>(s.disc_params()),
+      std::vector<int> disc_vector; // dummy
+      Eigen::VectorXd cont_params = s.cont_params();
+      std::vector<double> cont_vector(cont_params.size());
+      for (int i = 0; i < cont_params.size(); i++) cont_vector[i] = cont_params(i);
+      model.write_array(rng, cont_vector, disc_vector,
                         param_values, true, true, pstream);
       // values in param_values are column-major.
 
