@@ -7,6 +7,9 @@
 #include <stan/agrad/fwd/fvar.hpp>
 #include <stan/agrad/fwd/matrix/typedefs.hpp>
 #include <stan/math/matrix/multiply.hpp>
+#include <stan/agrad/fwd/matrix/multiply.hpp>
+#include <stan/math/matrix/inverse.hpp>
+#include <stan/agrad/fwd/matrix/inverse.hpp>
 
 namespace stan {
   namespace agrad {
@@ -15,6 +18,8 @@ namespace stan {
     inline 
     fvar<T>
     determinant(const Eigen::Matrix<fvar<T>, R, C>& m) {
+      using stan::math::multiply;
+
       stan::math::validate_square(m, "determinant");
       Eigen::Matrix<T,R,C> m_deriv(m.rows(), m.cols());
       Eigen::Matrix<T,R,C> m_val(m.rows(), m.cols());
@@ -28,11 +33,11 @@ namespace stan {
         }
       }
 
-      m_inv = m_val.inverse();
-      m_deriv = stan::math::multiply(m_inv, m_deriv);
+      m_inv = stan::math::inverse(m_val);
+      m_deriv = multiply(m_inv, m_deriv);
 
       result.val_ = m_val.determinant();
-      result.d_ = m_val.determinant() * m_deriv.trace();
+      result.d_ = result.val_ * m_deriv.trace();
 
       return result;
     }
