@@ -21,6 +21,7 @@
 #include <stan/gm/arguments/arg_random.hpp>
 #include <stan/gm/arguments/arg_output.hpp>
 
+#include <stan/mcmc/fixed_param_sampler.hpp>
 #include <stan/mcmc/hmc/static/adapt_unit_e_static_hmc.hpp>
 #include <stan/mcmc/hmc/static/adapt_diag_e_static_hmc.hpp>
 #include <stan/mcmc/hmc/static/adapt_dense_e_static_hmc.hpp>
@@ -38,7 +39,31 @@ namespace stan {
 
   namespace gm {
 
-    void write_stan(std::ostream* s, const char prefix = '\0') {
+    void write_iteration_csv(std::ostream& output_stream,
+                             const double lp,
+                             const std::vector<double>& model_values) {
+      output_stream << lp;
+      for (size_t i = 0; i < model_values.size(); ++i) {
+        output_stream << "," << model_values.at(i);
+      }
+      output_stream << std::endl;
+    }
+
+    template <class Model, class RNG>
+    void write_iteration(std::ostream& output_stream,
+                         Model& model,
+                         RNG& base_rng,
+                         double lp,
+                         std::vector<double>& cont_vector,
+                         std::vector<int>& disc_vector) {
+      std::vector<double> model_values;
+      model.write_array(base_rng, cont_vector, disc_vector, model_values,
+                        true, true, &std::cout);
+      write_iteration_csv(output_stream, lp, model_values);
+    }
+    
+
+    void write_stan(std::ostream* s, const std::string prefix = "") {
       if (!s) return;
       
       *s << prefix << " stan_version_major = " << stan::MAJOR_VERSION << std::endl;
@@ -47,7 +72,7 @@ namespace stan {
       
     }
     
-    void write_model(std::ostream* s, std::string model_name, const char prefix = '\0') {
+    void write_model(std::ostream* s, const std::string model_name, const std::string prefix = "") {
       if (!s) return;
       
       *s << prefix << " model = " << model_name << std::endl;
@@ -55,34 +80,68 @@ namespace stan {
     }
     
     void write_error_msg(std::ostream* error_stream,
-                         const std::domain_error& e) {
+                         const std::exception& e) {
       
       if (!error_stream) return;
       
       *error_stream << std::endl
-                    << "Informational Message: The current Metropolis proposal is about to be "
-                    << "rejected becuase of the following issue:"
+                    << "Informational Message: The current Metropolis proposal is about to be"
+                    << " rejected becuase of the following issue:"
                     << std::endl
                     << e.what() << std::endl
-                    << "If this warning occurs sporadically, such as for highly constrained "
-                    << "variable types like covariance matrices, then the sampler is fine,"
+                    << "If this warning occurs sporadically, such as for highly constrained"
+                    << " variable types like covariance matrices, then the sampler is fine,"
                     << std::endl
-                    << "but if this warning occurs often then your model may be either severely "
-                    << "ill-conditioned or misspecified."
+                    << "but if this warning occurs often then your model may be either"
+                    << " severely ill-conditioned or misspecified."
                     << std::endl;
       
     }
     
-    bool do_print(int n, int refresh) {
+    /** 
+     * Indicates whether it should print on the current iteration.
+     * The function returns:
+     *   true if refresh > 0 and 
+     *     (n == 0 or (n + 1) % refresh == 0 or special == true)
+     *   false otherwise.
+     * Examples:
+     *   if refresh = 0, always returns false.
+     *   if refresh = 10 and special == false, 
+     *      returns true for n = {0, 9, 19, ...},
+     *      returns false for n = {1 - 8, 10 - 18, 20 - 28, ...}.
+     *   if refresh = 10 and special == true, returns true for all n.
+     *
+     * @param n Iteration number
+     * @param special When true, returns true
+     * @param refresh Number of iterations to refresh
+     */
+    bool do_print(int n, bool special, int refresh) {
       return (refresh > 0) &&
-      (n == 0 || ((n + 1) % refresh == 0) );
+        (special || n == 0 || ((n + 1) % refresh == 0) );
+    }
+    
+    /**
+     * Indicates whether it should print on the current iteration.
+     * The function returns:
+     *   true if refresh > 0 and (n == 0 or (n + 1) % refresh == 0)
+     *   false otherwise.
+     * Examples:
+     *   if refresh = 0, always returns false.
+     *   if refresh = 10, returns true for n = {0, 9, 19, ...},
+     *      returns false for n = {1 - 8, 10 - 18, 20 - 28, ...}.
+     * 
+     * @param n Iteration number
+     * @param refresh Number of iterations to refresh
+     */
+    bool do_print(int n, int refresh) {
+      return do_print(n,false,refresh);
     }
 
     void print_progress(int m, int start, int finish, int refresh, bool warmup) {
       
       int it_print_width = std::ceil(std::log10(finish));
 
-      if (do_print(m, refresh) || (start + m + 1 == finish) ) {
+      if (do_print(m, (start + m + 1 == finish), refresh )) {
         
         std::cout << "Iteration: ";
         std::cout << std::setw(it_print_width) << m + 1 + start
@@ -157,7 +216,8 @@ namespace stan {
                 Model& model,
                 RNG& base_rng) {
       
-      run_markov_chain<Model, RNG>(sampler, num_samples, num_warmup, num_warmup + num_samples, num_thin,
+      run_markov_chain<Model, RNG>(sampler, num_samples, num_warmup, 
+                                   num_warmup + num_samples, num_thin,
                                    refresh, save, false,
                                    writer,
                                    init_s, model, base_rng);
@@ -175,7 +235,8 @@ namespace stan {
                                    algorithm->arg("hmc")->arg("engine")->arg("static"));
       
       double epsilon = dynamic_cast<real_argument*>(hmc->arg("stepsize"))->value();
-      double epsilon_jitter = dynamic_cast<real_argument*>(hmc->arg("stepsize_jitter"))->value();
+      double epsilon_jitter 
+        = dynamic_cast<real_argument*>(hmc->arg("stepsize_jitter"))->value();
       double int_time = dynamic_cast<real_argument*>(base->arg("int_time"))->value();
       
       dynamic_cast<Sampler*>(sampler)->set_nominal_stepsize_and_T(epsilon, int_time);
@@ -196,7 +257,8 @@ namespace stan {
                                    algorithm->arg("hmc")->arg("engine")->arg("nuts"));
 
       double epsilon = dynamic_cast<real_argument*>(hmc->arg("stepsize"))->value();
-      double epsilon_jitter = dynamic_cast<real_argument*>(hmc->arg("stepsize_jitter"))->value();
+      double epsilon_jitter 
+        = dynamic_cast<real_argument*>(hmc->arg("stepsize_jitter"))->value();
       int max_depth = dynamic_cast<int_argument*>(base->arg("max_depth"))->value();
       
       dynamic_cast<Sampler*>(sampler)->set_nominal_stepsize(epsilon);
@@ -227,8 +289,9 @@ namespace stan {
       try {
         sampler->z().q = cont_params;
         sampler->init_stepsize();
-      } catch (std::runtime_error e) {
-        std::cout << e.what() << std::endl;
+      } catch (const std::exception& e) {
+        std::cout << "Exception initializing step size." << std::endl
+                  << e.what() << std::endl;
         return false;
       }
       
@@ -255,11 +318,14 @@ namespace stan {
       
       init_adapt<Sampler>(sampler, adapt, cont_params);
       
-      unsigned int init_buffer = dynamic_cast<u_int_argument*>(adapt->arg("init_buffer"))->value();
-      unsigned int term_buffer = dynamic_cast<u_int_argument*>(adapt->arg("term_buffer"))->value();
+      unsigned int init_buffer 
+        = dynamic_cast<u_int_argument*>(adapt->arg("init_buffer"))->value();
+      unsigned int term_buffer 
+        = dynamic_cast<u_int_argument*>(adapt->arg("term_buffer"))->value();
       unsigned int window = dynamic_cast<u_int_argument*>(adapt->arg("window"))->value();
       
-      dynamic_cast<Sampler*>(sampler)->set_window_params(num_warmup, init_buffer, term_buffer, window, &std::cout);
+      dynamic_cast<Sampler*>(sampler)->set_window_params(num_warmup, init_buffer, 
+                                                         term_buffer, window, &std::cout);
       
       return true;
       
@@ -297,7 +363,8 @@ namespace stan {
       //////////////////////////////////////////////////
       
       unsigned int random_seed = 0;
-      u_int_argument* random_arg = dynamic_cast<u_int_argument*>(parser.arg("random")->arg("seed"));
+      u_int_argument* random_arg 
+        = dynamic_cast<u_int_argument*>(parser.arg("random")->arg("seed"));
       
       if (random_arg->is_default()) {
         random_seed = (boost::posix_time::microsec_clock::universal_time() -
@@ -322,7 +389,8 @@ namespace stan {
       //////////////////////////////////////////////////
       
       // Data input
-      std::string data_file = dynamic_cast<string_argument*>(parser.arg("data")->arg("file"))->value();
+      std::string data_file 
+        = dynamic_cast<string_argument*>(parser.arg("data")->arg("file"))->value();
       
       std::fstream data_stream(data_file.c_str(),
                                std::fstream::in);
@@ -361,15 +429,15 @@ namespace stan {
       Eigen::VectorXd cont_params = Eigen::VectorXd::Zero(model.num_params_r());
 
       if (output_stream) {
-        write_stan(output_stream, '#');
-        write_model(output_stream, model.model_name(), '#');
-        parser.print(output_stream, '#');
+        write_stan(output_stream, "#");
+        write_model(output_stream, model.model_name(), "#");
+        parser.print(output_stream, "#");
       }
       
       if (diagnostic_stream) {
-        write_stan(diagnostic_stream, '#');
-        write_model(diagnostic_stream, model.model_name(), '#');
-        parser.print(diagnostic_stream, '#');
+        write_stan(diagnostic_stream, "#");
+        write_model(diagnostic_stream, model.model_name(), "#");
+        parser.print(diagnostic_stream, "#");
       }
       
       int num_init_tries = -1;
@@ -389,21 +457,24 @@ namespace stan {
           Eigen::VectorXd init_grad = Eigen::VectorXd::Zero(model.num_params_r());
           
           try {
-            init_log_prob 
-              = stan::model::log_prob_grad<true, true>(model, cont_params, init_grad, &std::cout);
-          } catch (std::domain_error e) {
-            std::cout << "Rejecting initialization at zero because of log_prob_grad failure." << std::endl;
+            stan::model::gradient(model, cont_params, init_log_prob, init_grad, &std::cout);
+          } catch (const std::exception& e) {
+            std::cout << "Rejecting initialization at zero because of gradient failure."
+                      << std::endl 
+                      << e.what() << std::endl;
             return error_codes::OK;
           }
           
           if (!boost::math::isfinite(init_log_prob)) {
-            std::cout << "Rejecting initialization at zero because of vanishing density." << std::endl;
+            std::cout << "Rejecting initialization at zero because of vanishing density." 
+                      << std::endl;
             return 0;
           }
           
           for (int i = 0; i < init_grad.size(); ++i) {
             if (!boost::math::isfinite(init_grad[i])) {
-              std::cout << "Rejecting initialization at zero because of divergent gradient." << std::endl;
+              std::cout << "Rejecting initialization at zero because of divergent gradient."
+                        << std::endl;
               return 0;
             }
           }
@@ -431,11 +502,11 @@ namespace stan {
             // FIXME: allow config vs. std::cout
             double init_log_prob;
             try {
-              init_log_prob
-                = stan::model::log_prob_grad<true, true>(model, cont_params, init_grad, &std::cout);
-            } catch (std::domain_error e) {
+              stan::model::gradient(model, cont_params, init_log_prob, init_grad, &std::cout);
+            } catch (const std::exception& e) {
               write_error_msg(&std::cout, e);
-              std::cout << "Rejecting proposed initial value with zero density." << std::endl;
+              std::cout << "Rejecting proposed initial value with zero density." 
+                        << std::endl;
               init_log_prob = -std::numeric_limits<double>::infinity();
             }
             
@@ -477,10 +548,8 @@ namespace stan {
           model.transform_inits(init_var_context, cont_params);
         
         } catch (const std::exception& e) {
-          std::cerr << "Error during user-specified initialization:"
-                    << std::endl
-                    << e.what()
-                    << std::endl;
+          std::cerr << "Error during user-specified initialization:" << std::endl
+                    << e.what() << std::endl;
           return -5;
         }
         
@@ -488,23 +557,27 @@ namespace stan {
         Eigen::VectorXd init_grad = Eigen::VectorXd::Zero(model.num_params_r());
         
         try {
-        
-          init_log_prob
-            = stan::model::log_prob_grad<true, true>(model, cont_params, init_grad, &std::cout);
-
-        } catch (std::domain_error e) {
-          std::cout << "Rejecting user-specified initialization because of log_prob_grad failure." << std::endl;
+          stan::model::gradient(model, cont_params, init_log_prob, init_grad, &std::cout);
+        } catch (const std::exception& e) {
+          std::cout 
+            << "Rejecting user-specified initialization because of gradient failure."
+            << std::endl
+            << e.what() << std::endl;
           return 0;
         }
         
         if (!boost::math::isfinite(init_log_prob)) {
-          std::cout << "Rejecting user-specified initialization because of vanishing density." << std::endl;
+          std::cout 
+            << "Rejecting user-specified initialization because of vanishing density."
+            << std::endl;
           return 0;
         }
         
         for (int i = 0; i < init_grad.size(); ++i) {
           if (!boost::math::isfinite(init_grad[i])) {
-            std::cout << "Rejecting user-specified initialization because of divergent gradient." << std::endl;
+            std::cout 
+              << "Rejecting user-specified initialization because of divergent gradient."
+              << std::endl;
             return 0;
           }
         }
@@ -535,16 +608,19 @@ namespace stan {
                          (test->arg("gradient")->arg("error"))->value();
           
           int num_failed
-            = stan::model::test_gradients<true,true>(model,cont_vector, disc_vector, epsilon, error, std::cout);
+            = stan::model::test_gradients<true,true>(model,cont_vector, disc_vector, 
+                                                     epsilon, error, std::cout);
           
           if (output_stream) {
             num_failed
-              = stan::model::test_gradients<true,true>(model,cont_vector, disc_vector, epsilon, error, *output_stream);
+              = stan::model::test_gradients<true,true>(model,cont_vector, disc_vector,
+                                                       epsilon, error, *output_stream);
           }
           
           if (diagnostic_stream) {
             num_failed
-              = stan::model::test_gradients<true,true>(model,cont_vector, disc_vector, epsilon, error, *diagnostic_stream);
+              = stan::model::test_gradients<true,true>(model,cont_vector, disc_vector, 
+                                                       epsilon, error, *diagnostic_stream);
           }
           
           (void) num_failed; // FIXME: do something with the number failed
@@ -559,7 +635,6 @@ namespace stan {
       //////////////////////////////////////////////////
       
       if (parser.arg("method")->arg("optimize")) {
-        
         std::vector<double> cont_vector(cont_params.size());
         for (int i = 0; i < cont_params.size(); ++i)
           cont_vector.at(i) = cont_params(i);
@@ -571,12 +646,20 @@ namespace stan {
         int num_iterations = dynamic_cast<int_argument*>(
                              parser.arg("method")->arg("optimize")->arg("iter"))->value();
 
-        bool save_iterations = dynamic_cast<bool_argument*>(
-                               parser.arg("method")->arg("optimize")->arg("save_iterations"))->value();
-
+        bool save_iterations 
+          = dynamic_cast<bool_argument*>(parser.arg("method")
+                                         ->arg("optimize")
+                                         ->arg("save_iterations"))->value();
         if (output_stream) {
-          *output_stream << "lp__,";
-          model.write_csv_header(*output_stream);
+          std::vector<std::string> names;
+          names.push_back("lp__");
+          model.constrained_param_names(names,true,true);
+
+          (*output_stream) << names.at(0);
+          for (size_t i = 1; i < names.size(); ++i) {
+            (*output_stream) << "," << names.at(i);
+          }
+          (*output_stream) << std::endl;
         }
 
         double lp(0);
@@ -594,10 +677,8 @@ namespace stan {
           double lastlp = lp - 1;
           std::cout << "Initial log joint probability = " << lp << std::endl;
           if (output_stream && save_iterations) {
-            *output_stream << lp << ',';
-            model.write_csv(base_rng, cont_vector, disc_vector,
-                            *output_stream, &std::cout);
-            output_stream->flush();
+            write_iteration(*output_stream, model, base_rng,
+                            lp, cont_vector, disc_vector);
           }
 
           int m = 0;
@@ -615,34 +696,30 @@ namespace stan {
             }
             m++;
             if (output_stream && save_iterations) {
-              *output_stream << lp << ',';
-              model.write_csv(base_rng, cont_vector, disc_vector,
-                              *output_stream, &std::cout);
-              output_stream->flush();
+              write_iteration(*output_stream, model, base_rng,
+                              lp, cont_vector, disc_vector);
             }
 
           }
           return_code = error_codes::OK;
         } else if (algo->value() == "newton") {
-          
           std::vector<double> gradient;
           try {
             lp = model.template log_prob<false, false>(cont_vector, disc_vector, &std::cout);
-          } catch (std::domain_error e) {
+          } catch (const std::exception& e) {
             write_error_msg(&std::cout, e);
             lp = -std::numeric_limits<double>::infinity();
           }
           
           std::cout << "initial log joint probability = " << lp << std::endl;
           if (output_stream && save_iterations) {
-            *output_stream << lp << ',';
-            model.write_csv(base_rng, cont_vector, disc_vector,
-                            *output_stream, &std::cout);
-            output_stream->flush();
+            write_iteration(*output_stream, model, base_rng,
+                            lp, cont_vector, disc_vector);
           }
 
-          double lastlp = lp - 1;
+          double lastlp = lp * 1.1;
           int m = 0;
+          std::cout << "(lp - lastlp) / lp > 1e-8: " << ((lp - lastlp) / fabs(lp)) << std::endl;
           while ((lp - lastlp) / fabs(lp) > 1e-8) {
             
             lastlp = lp;
@@ -656,9 +733,8 @@ namespace stan {
             m++;
 
             if (output_stream && save_iterations) {
-              *output_stream << lp << ',';
-              model.write_csv(base_rng, cont_vector, disc_vector,
-                              *output_stream, &std::cout);
+              write_iteration(*output_stream, model, base_rng,
+                              lp, cont_vector, disc_vector);
             }
             
           }
@@ -681,10 +757,8 @@ namespace stan {
           
           std::cout << "initial log joint probability = " << lp << std::endl;
           if (output_stream && save_iterations) {
-            *output_stream << lp << ',';
-            model.write_csv(base_rng, cont_vector, disc_vector,
-                            *output_stream, &std::cout);
-            output_stream->flush();
+            write_iteration(*output_stream, model, base_rng,
+                            lp, cont_vector, disc_vector);
           }
 
           int ret = 0;
@@ -706,23 +780,27 @@ namespace stan {
             lp = bfgs.logp();
             bfgs.params_r(cont_vector);
             
-            if (do_print(bfgs.iter_num(), refresh) || ret != 0 || !bfgs.note().empty()) {
+            if (do_print(bfgs.iter_num(), ret != 0 || !bfgs.note().empty(),refresh)) {
               std::cout << " " << std::setw(7) << bfgs.iter_num() << " ";
-              std::cout << " " << std::setw(12) << std::setprecision(6) << lp << " ";
-              std::cout << " " << std::setw(12) << std::setprecision(6) << bfgs.prev_step_size() << " ";
-              std::cout << " " << std::setw(12) << std::setprecision(6) << bfgs.curr_g().norm() << " ";
-              std::cout << " " << std::setw(10) << std::setprecision(4) << bfgs.alpha() << " ";
-//              std::cout << " " << std::setw(10) << std::setprecision(4) << bfgs.alpha0() << " ";
-              std::cout << " " << std::setw(7) << bfgs.grad_evals() << " ";
+              std::cout << " " << std::setw(12) << std::setprecision(6) 
+                        << lp << " ";
+              std::cout << " " << std::setw(12) << std::setprecision(6) 
+                        << bfgs.prev_step_size() << " ";
+              std::cout << " " << std::setw(12) << std::setprecision(6) 
+                        << bfgs.curr_g().norm() << " ";
+              std::cout << " " << std::setw(10) << std::setprecision(4) 
+                        << bfgs.alpha() << " ";
+              // std::cout << " " << std::setw(10) << std::setprecision(4) 
+              // << bfgs.alpha0() << " ";
+              std::cout << " " << std::setw(7) 
+                        << bfgs.grad_evals() << " ";
               std::cout << " " << bfgs.note() << " ";
               std::cout << std::endl;
             }
             
             if (output_stream && save_iterations) {
-              *output_stream << lp << ',';
-              model.write_csv(base_rng, cont_vector, disc_vector,
-                              *output_stream, &std::cout);
-              output_stream->flush();
+              write_iteration(*output_stream, model, base_rng,
+                              lp, cont_vector, disc_vector);
             }
           }
           
@@ -740,10 +818,8 @@ namespace stan {
         }
 
         if (output_stream) {
-          *output_stream << lp << ',';
-          model.write_csv(base_rng, cont_vector, disc_vector,
-                          *output_stream, &std::cout);
-          output_stream->flush();
+          write_iteration(*output_stream, model, base_rng,
+                          lp, cont_vector, disc_vector);
           output_stream->close();
           delete output_stream;
         }
@@ -756,12 +832,13 @@ namespace stan {
       
       if (parser.arg("method")->arg("sample")) {
         
-        
         // Check timing
         clock_t start_check = clock();
         
+        double init_log_prob;
         Eigen::VectorXd init_grad = Eigen::VectorXd::Zero(model.num_params_r());
-        stan::model::log_prob_grad<true, true>(model, cont_params, init_grad, &std::cout);
+        
+        stan::model::gradient(model, cont_params, init_log_prob, init_grad, &std::cout);
         
         clock_t end_check = clock();
         double deltaT = (double)(end_check - start_check) / CLOCKS_PER_SEC;
@@ -803,7 +880,18 @@ namespace stan {
                                       parser.arg("method")->arg("sample")->arg("adapt"));
         bool adapt_engaged = dynamic_cast<bool_argument*>(adapt->arg("engaged"))->value();
         
-        if (algo->value() == "rwm") {
+        if (algo->value() == "fixed_param") {
+          
+          sampler_ptr = new stan::mcmc::fixed_param_sampler();
+          
+          adapt_engaged = false;
+          
+          if (num_warmup != 0) {
+            std::cout << "Warning: warmup will be skipped for the fixed parameter sampler!" << std::endl;
+            num_warmup = 0;
+          }
+          
+        } else if (algo->value() == "rwm") {
           
           std::cout << algo->arg("rwm")->description() << std::endl;
           return 0;
@@ -830,7 +918,9 @@ namespace stan {
             metric_index = 2;
           }
           
-          int sampler_select = engine_index + 10 * metric_index + 100 * static_cast<int>(adapt_engaged);
+          int sampler_select = engine_index 
+            + 10 * metric_index 
+            + 100 * static_cast<int>(adapt_engaged);
           
           switch (sampler_select) {
               
@@ -896,7 +986,8 @@ namespace stan {
               typedef stan::mcmc::adapt_diag_e_static_hmc<Model, rng_t> sampler;
               sampler_ptr = new sampler(model, base_rng, &std::cout, &std::cout);
               if (!init_static_hmc<sampler>(sampler_ptr, algo)) return 0;
-              if (!init_windowed_adapt<sampler>(sampler_ptr, adapt, num_warmup, cont_params)) return 0;
+              if (!init_windowed_adapt<sampler>(sampler_ptr, adapt, num_warmup, cont_params)) 
+                return 0;
               break;
             }
             
@@ -904,7 +995,8 @@ namespace stan {
               typedef stan::mcmc::adapt_diag_e_nuts<Model, rng_t> sampler;
               sampler_ptr = new sampler(model, base_rng, &std::cout, &std::cout);
               if (!init_nuts<sampler>(sampler_ptr, algo)) return 0;
-              if (!init_windowed_adapt<sampler>(sampler_ptr, adapt, num_warmup, cont_params)) return 0;
+              if (!init_windowed_adapt<sampler>(sampler_ptr, adapt, num_warmup, cont_params)) 
+                return 0;
               break;
             }
             
@@ -912,7 +1004,8 @@ namespace stan {
               typedef stan::mcmc::adapt_dense_e_static_hmc<Model, rng_t> sampler;
               sampler_ptr = new sampler(model, base_rng, &std::cout, &std::cout);
               if (!init_static_hmc<sampler>(sampler_ptr, algo)) return 0;
-              if (!init_windowed_adapt<sampler>(sampler_ptr, adapt, num_warmup, cont_params)) return 0;
+              if (!init_windowed_adapt<sampler>(sampler_ptr, adapt, num_warmup, cont_params)) 
+                return 0;
               break;
             }
             
@@ -920,7 +1013,8 @@ namespace stan {
               typedef stan::mcmc::adapt_dense_e_nuts<Model, rng_t> sampler;
               sampler_ptr = new sampler(model, base_rng, &std::cout, &std::cout);
               if (!init_nuts<sampler>(sampler_ptr, algo)) return 0;
-              if (!init_windowed_adapt<sampler>(sampler_ptr, adapt, num_warmup, cont_params)) return 0;
+              if (!init_windowed_adapt<sampler>(sampler_ptr, adapt, num_warmup, cont_params))
+                return 0;
               break;
             }
             
