@@ -1,6 +1,7 @@
 #ifndef __STAN__MATH__MATRIX__SOFTMAX_HPP__
 #define __STAN__MATH__MATRIX__SOFTMAX_HPP__
 
+#include <cmath>
 #include <stan/math/matrix/Eigen.hpp>
 #include <stan/math/matrix/validate_nonzero_size.hpp>
 
@@ -9,6 +10,7 @@ namespace stan {
 
    /**
      * Return the softmax of the specified vector.
+     *
      * @tparam T Scalar type of values in vector.
      * @param[in] v Vector to transform.
      * @return Unit simplex result of the softmax transform of the vector.
@@ -22,11 +24,11 @@ namespace stan {
       T sum(0.0);
       T max_v = v.maxCoeff();
       for (int i = 0; i < v.size(); ++i) {
-        theta[i] = exp(v[i] - max_v);
-        sum += theta[i];
+        theta(i) = exp(v(i) - max_v); // extra work for (v[i] == max_v)
+        sum += theta(i);              // extra work vs. sum() w. auto-diff
       }
       for (int i = 0; i < v.size(); ++i)
-        theta[i] /= sum;
+        theta(i) /= sum;
       return theta;
     }
 
