@@ -13,10 +13,9 @@
 #include <boost/exception/all.hpp>
 #include <boost/random/linear_congruential.hpp>
 
-#include <stan/agrad/agrad.hpp>
-#include <stan/agrad/matrix.hpp>
-#include <stan/agrad/rev/error_handling/matrix/check_pos_definite.hpp>
-#include <stan/agrad/partials_vari.hpp>
+#include <stan/agrad/rev.hpp>
+#include <stan/agrad/rev/matrix.hpp>
+
 #include <stan/gm/command.hpp>
 #include <stan/io/cmd_line.hpp>
 #include <stan/io/dump.hpp>
