@@ -5,8 +5,10 @@
 #include <boost/random/variate_generator.hpp>
 
 #include <boost/math/special_functions/digamma.hpp>
-#include <stan/agrad.hpp>
+#include <stan/agrad/partials_vari.hpp>
 #include <stan/math/error_handling.hpp>
+#include <stan/math/constants.hpp>
+#include <stan/math/functions/multiply_log.hpp>
 #include <stan/math/functions/value_of.hpp>
 #include <stan/meta/traits.hpp>
 #include <stan/prob/traits.hpp>
@@ -242,11 +244,6 @@ namespace stan {
       agrad::OperandsAndPartials<T_shape, T_inv_scale> 
         operands_and_partials(alpha, beta);
           
-      std::fill(operands_and_partials.all_partials,
-                operands_and_partials.all_partials 
-                + operands_and_partials.nvaris,
-                0.0);
-          
       // Explicit return for extreme values
       // The gradients are technically ill-defined, but treated as zero
       for (size_t i = 0; i < stan::length(n); i++) {
@@ -388,11 +385,6 @@ namespace stan {
       agrad::OperandsAndPartials<T_shape, T_inv_scale> 
         operands_and_partials(alpha, beta);
           
-      std::fill(operands_and_partials.all_partials,
-                operands_and_partials.all_partials 
-                + operands_and_partials.nvaris,
-                0.0);
-          
       // Explicit return for extreme values
       // The gradients are technically ill-defined, but treated as zero
       for (size_t i = 0; i < stan::length(n); i++) {
@@ -515,11 +507,6 @@ namespace stan {
       agrad::OperandsAndPartials<T_shape, T_inv_scale> 
         operands_and_partials(alpha, beta);
           
-      std::fill(operands_and_partials.all_partials,
-                operands_and_partials.all_partials 
-                + operands_and_partials.nvaris,
-                0.0);
-          
       // Explicit return for extreme values
       // The gradients are technically ill-defined, but treated as zero
       for (size_t i = 0; i < stan::length(n); i++) {
