@@ -10,7 +10,7 @@
 #include <boost/multi_array.hpp>
 #include <boost/throw_exception.hpp>
 #include <boost/math/tools/promotion.hpp>
-#include <stan/agrad/matrix.hpp>
+#include <stan/agrad/rev/matrix.hpp>
 #include <stan/math.hpp>
 #include <stan/math/matrix.hpp>
 #include <stan/math/matrix/sum.hpp>
